@@ -49,18 +49,7 @@ class graph:
         self.label_names = label_names
         self.node_names = node_names
 
-        #Coordinates of sparse matrix for passing to C code
-        I,J,V = sparse.find(self.weight_matrix)
-        ind = np.argsort(I)
-        self.I,self.J,self.V = I[ind], J[ind], V[ind]
-        self.K = np.array((self.I[1:] - self.I[:-1]).nonzero()) + 1
-        self.K = np.append(0,np.append(self.K,len(self.I)))
-
-        #For passing to C code
-        self.I = np.ascontiguousarray(self.I, dtype=np.int32)
-        self.J = np.ascontiguousarray(self.J, dtype=np.int32)
-        self.V = np.ascontiguousarray(self.V, dtype=np.float64)
-        self.K = np.ascontiguousarray(self.K, dtype=np.int32)
+        self.__ccode_init__()
 
         self.eigendata = {}
         normalizations = ['combinatorial','randomwalk','normalized']
@@ -76,6 +65,23 @@ class graph:
             self.eigendata[norm]['tol'] = None
             self.eigendata[norm]['q'] = None
 
+    def __ccode_init__(self):
+
+        #Coordinates of sparse matrix for passing to C code
+        I,J,V = sparse.find(self.weight_matrix)
+        ind = np.argsort(I)
+        self.I,self.J,self.V = I[ind], J[ind], V[ind]
+        self.K = np.array((self.I[1:] - self.I[:-1]).nonzero()) + 1
+        self.K = np.append(0,np.append(self.K,len(self.I)))
+        self.Vinv = 1/self.V
+
+        #For passing to C code
+        self.I = np.ascontiguousarray(self.I, dtype=np.int32)
+        self.J = np.ascontiguousarray(self.J, dtype=np.int32)
+        self.V = np.ascontiguousarray(self.V, dtype=np.float64)
+        self.Vinv = np.ascontiguousarray(self.Vinv, dtype=np.float64)
+        self.K = np.ascontiguousarray(self.K, dtype=np.int32)
+
     def subgraph(self,ind):
         """Sub-Graph
         ======
@@ -114,6 +120,35 @@ class graph:
         d = self.weight_matrix*np.ones(self.num_nodes)
         return d
 
+    def neighbors(self, i, return_weights=False):
+        """Neighbors
+        ======
+
+        Returns neighbors of node i.
+
+        Parameters
+        ----------
+        i : int 
+            Index of vertex to return neighbors of.
+        return_weights : bool (optional), default=False
+            Whether to return the weights of neighbors as well.
+
+        Returns
+        -------
+        N : numpy array, int
+            Array of nearest neighbor indices.
+        W : numpy array, float
+            Weights of edges to neighbors. 
+        """
+        
+        N = self.weight_matrix[i,:].nonzero()[1]
+        N = N[N != i]
+
+        if return_weights:
+            return N, self.weight_matrix[i,N].toarray().flatten()
+        else:
+            return N
+
     def fiedler_vector(self, return_value=False, tol=1e-8):
         """Fiedler Vector
         ======
@@ -922,8 +957,85 @@ class graph:
         else:
             return dist_func
 
+    def distance(self, i, j, return_path=False, return_distance_vector=False):
+        """Graph distance
+        ======
+        
+        Computes the shortest path distance between two points. Can also return the shortest path.
+        Edges are weighted by the reciprocals of the edge weights \\(w_{ij}^{-1}\\).
 
-    def dijkstra(self, bdy_set, bdy_val=0, f=1, max_dist=np.inf, return_cp=False):
+        Parameters
+        ----------
+        i : int 
+            First index
+        j : int 
+            Second index
+        return_path : bool (optional), default = False
+            Whether to return optimal path.
+        return_distance_vector : bool (optional), default = False
+            Whether to return distance vector to node i.
+
+        Returns 
+        -------
+        d : float
+            Distance
+        path : numpy array, int (optional)
+            Indices of optimal path
+        v : numpy array, float (optional)
+            Distance vector to node i
+        """
+
+        v = self.dijkstra([i],reciprocal_weights=True)
+        d = v[j]
+        if return_path:
+            p = j
+            path = [p]
+            while p != i:
+                nn, w = self.neighbors(p, return_weights=True)
+                k = np.argmin(v[nn] + w**-1)
+                p = nn[k]
+                path += [p]
+            path = np.array(path)
+            if return_distance_vector:
+                return d,path,v
+            else:
+                return d,path
+        else:
+            if return_distance_vector:
+                return d,v
+            else:
+                return d
+
+    def distance_matrix(self, centered=False):
+        """Graph distance matrix
+        ======
+        
+        Computes the shortest path distance between all pairs of points in the graph.
+        Edges are weighted by the reciprocals of the edge weights \\(w_{ij}^{-1}\\).
+
+        Parameters
+        -------
+        centered : bool (optional), default=False
+            Whether to center the distance matrix, as in ISOMAP.
+
+        Returns 
+        -------
+        T : numpy array, float
+            Distance matrix
+        """
+
+        n = self.num_nodes
+        T = np.zeros((n,n))
+        for i in range(n):
+            d,T[i,:] = self.distance(i,i,return_distance_vector=True)
+
+        if centered:
+            J = np.eye(n)  - (1/n)*np.ones((n,n))
+            T = -0.5*J@T@J
+
+        return T
+
+    def dijkstra(self, bdy_set, bdy_val=0, f=1, max_dist=np.inf, return_cp=False, reciprocal_weights=False):
         """Dijkstra's algorithm
         ======
 
@@ -958,6 +1070,9 @@ class graph:
         return_cp : bool (optional), default=False
             Whether to return closest point. Nodes with distance greater than max_dist 
             contain `-1` for closest point index.
+        reciprocal_weights : bool (optional), default=False
+            Whether to use the reciprocals of the weights \\(w_{ij}^{-1}\\) in the definition of 
+            graph distance. 
 
         Returns
         -------
@@ -1010,7 +1125,10 @@ class graph:
         bdy_val = np.ascontiguousarray(bdy_val,dtype=np.float64)
         f = np.ascontiguousarray(f,dtype=np.float64)
 
-        cextensions.dijkstra(dist_func,cp,self.J,self.K,self.V,bdy_set,bdy_val,f,1.0,max_dist)
+        if reciprocal_weights:
+            cextensions.dijkstra(dist_func,cp,self.J,self.K,self.Vinv,bdy_set,bdy_val,f,1.0,max_dist)
+        else:
+            cextensions.dijkstra(dist_func,cp,self.J,self.K,self.V,bdy_set,bdy_val,f,1.0,max_dist)
 
         if return_cp:
             return dist_func, cp
@@ -1207,7 +1325,7 @@ class graph:
         filename += '.pkl'
         with open(filename, 'rb') as inp:
             G = pickle.load(inp)
-
+        G.__ccode_init__()
         return G
 
 
@@ -1254,7 +1372,7 @@ class graph:
 
         return u
 
-    def draw(self,X=None,c=None,cmap='viridis',markersize=None,linewidth=None,edges=True):
+    def draw(self,X=None,c=None,cmap='viridis',markersize=None,linewidth=None,edges=True,linecolor='black'):
         """Draw Graph
         ======
 
@@ -1274,6 +1392,14 @@ class graph:
             Linewidth.
         edges : bool (optional)
             Whether to plot edges (default=True)
+        linecolor : string (optional)
+            Color for lines (default='black')
+
+        Parameters
+        ----------
+        X : (n,2) numpy array
+            Returns coordinates of points.
+
         """
 
         plt.figure()
@@ -1281,11 +1407,12 @@ class graph:
 
         #If points are not provided, we use metric MDS
         if X is None:
-            J = np.eye(n) - (1/n)*np.ones((n,n))
-            dist = np.zeros((n,n))
-            for i in range(n):
-                dist[i,:] = self.dijkstra([i])
-            H = -(1/2)*J@dist@J
+            #J = np.eye(n) - (1/n)*np.ones((n,n))
+            #dist = np.zeros((n,n))
+            #for i in range(n):
+            #    dist[i,:] = self.dijkstra([i])
+            #H = -(1/2)*J@dist@J
+            H = self.distance_matrix(centered=True)
 
             #Need to sort eigenvalues, since H may not be positive semidef
             vals,V = sparse.linalg.eigsh(H,k=10,which='LM')
@@ -1319,10 +1446,11 @@ class graph:
                 nn = self.weight_matrix[i,:].nonzero()[1]
                 for j in nn:
                     if linewidth is None:
-                        plt.plot([x[i],x[j]],[y[i],y[j]],c='black',zorder=0)
+                        plt.plot([x[i],x[j]],[y[i],y[j]],color=linecolor,zorder=0)
                     else:
-                        plt.plot([x[i],x[j]],[y[i],y[j]],c='black',linewidth=linewidth,zorder=0)
+                        plt.plot([x[i],x[j]],[y[i],y[j]],color=linecolor,linewidth=linewidth,zorder=0)
 
+        return X
 
 
 
