@@ -331,7 +331,7 @@ class ssl:
 
             outfile = os.path.join(results_dir, tag+self.get_accuracy_filename())
             if (not overwrite) and os.path.exists(outfile):
-                print('Aborting: SSL trial already completed, and overwrite is False.')
+                print('Aborting: SSL trial ('+self.get_accuracy_filename()+') already completed , and overwrite is False.')
                 return
             f = open(outfile,"w")
             #now = datetime.datetime.now()
@@ -457,7 +457,7 @@ class ssl:
         Returns
         -------
         u : (n,k) numpy array, float
-            Probabilities computed by graph-based learning for each node and each class.
+            Per-class scores computed by graph-based learning for each node and each class. For some methods these are probabilities (i.e., for Laplace learning), while for others they can take on negative values (e.g., Poisson learning). The class label prediction is either the argmax or argmin over the rows of u (most methods are argmax, except distance-function based methods like nearest neighbor and peikonal).
         """
 
         if self.graph is None:
@@ -902,7 +902,7 @@ class volume_mbo(ssl):
         train_labels = np.ascontiguousarray(train_labels,dtype=np.int32)
         ClassCounts = np.ascontiguousarray(self.class_counts,dtype=np.int32)
 
-        cextensions.volume_mbo(u,WI,WJ,WV,train_ind,train_labels,ClassCounts,k,1.0,self.temperature,self.volume_constraint)
+        cextensions.volume_mbo(u,WJ,WI,WV,train_ind,train_labels,ClassCounts,k,1.0,self.temperature,self.volume_constraint)
 
         #Set given labels and convert to vector format
         u[train_ind] = train_labels
@@ -1193,6 +1193,7 @@ class laplace(ssl):
             fname += '_meanshift'
             self.name += ' with meanshift'
         if self.order > 1:
+            fname += '_order%d'%int(self.order)
             self.name += ' order %d'%int(self.order)
         if np.max(self.tau) > 0:
             fname += '_tau_%.3f'%np.max(self.tau)
@@ -1201,6 +1202,7 @@ class laplace(ssl):
         self.accuracy_filename = fname
 
 
+
     def _fit(self, train_ind, train_labels, all_labels=None):
 
         #Reweighting
@@ -1694,8 +1696,8 @@ class plaplace(ssl):
             Value of p in the p-Laplace equation (\\( 2 \\leq p \\leq \\infty\\).
         max_num_it : int (optional), default=1e5
             Maximum number of iterations
-        tol : float (optional), default=1e-3
-            Tolerance with which to solve the equation.
+        tol : float (optional)
+            Tolerance with which to solve the equation. Default tol=0.1 for fast=False and tol=1e-5 otherwise.
         fast : bool (optional), default=True
             Whether to use constant \\(w_{ij}=1\\) weights for the infinity-Laplacian
             which allows a faster algorithm to be used.
@@ -1712,6 +1714,8 @@ class plaplace(ssl):
         self.onevsrest = True
         self.fast = fast
 
+        if fast:
+            self.tol = 1e-5
         #Setup accuracy filename and model name
         self.accuracy_filename = '_plaplace_p%.2f'%self.p 
         self.name = 'p-Laplace (p=%.2f)'%self.p
