@@ -10,6 +10,7 @@ import numpy as np
 from scipy import spatial
 from scipy import sparse
 import os
+import sys
 from . import utils
 
 #Directory to store knn data
@@ -95,8 +96,8 @@ def knn(data, k, kernel='gaussian', eta=None, symmetrize=True, metric='raw', sim
         where \\(d_k(x_i)\\) is the distance from \\(x_i\\) to its kth nearest neighbor.
     symmetrize : bool (optional), default=True, except when kernel='singular'
         Whether or not to symmetrize the weight matrix before returning. Symmetrization is 
-        performed by returning \\( (W + W^T)/2 \\), except for when kernel='distance, in 
-        which case the symmetrized edge weights are the true distances, kernel='uniform', 
+        performed by returning \\( (W + W^T)/2 \\), except for when kernel='distance','singular', in 
+        which case the symmetrized edge weights are the true distances (or inverses), kernel='uniform', 
         where the weights are all 0/1, or kernel='symgaussian', where the same formula 
         is used for symmetry. Default for symmetrization is True, unless the kernel is
         'singular', in which case it is False.
@@ -113,6 +114,9 @@ def knn(data, k, kernel='gaussian', eta=None, symmetrize=True, metric='raw', sim
     W : (n,n) scipy sparse matrix, float 
         Sparse weight matrix.
     """
+    
+    #Self is counted in knn data, so add one
+    k += 1
 
     #If knn_data provided
     if knn_data is not None:
@@ -150,7 +154,6 @@ def knn(data, k, kernel='gaussian', eta=None, symmetrize=True, metric='raw', sim
             weights = knn_dist
             weights[knn_dist==0] = 1
             weights = 1/weights
-            symmetrize = False
         else:
             sys.exit('Invalid choice of kernel: ' + kernel)
 
@@ -172,17 +175,17 @@ def knn(data, k, kernel='gaussian', eta=None, symmetrize=True, metric='raw', sim
     W = sparse.coo_matrix((weights, (self_ind, knn_ind)),shape=(n,n)).tocsr()
 
     if symmetrize:
-        if kernel in ['distance','uniform']:
+        if kernel in ['distance','uniform','singular']:
             W = utils.sparse_max(W, W.transpose())
         elif kernel == 'symgaussian':
             W = W + W.T.multiply(W.T > W) - W.multiply(W.T > W)
         else:
             W = (W + W.transpose())/2;
 
-
+    W.setdiag(0)
     return W
 
-def epsilon_ball(data, epsilon, kernel='gaussian', features=None, epsilon_f=1, eta=None, zero_diagonal=False):
+def epsilon_ball(data, epsilon, kernel='gaussian', features=None, epsilon_f=1, eta=None):
     """Epsilon ball weight matrix
     ======
 
@@ -190,6 +193,7 @@ def epsilon_ball(data, epsilon, kernel='gaussian', features=None, epsilon_f=1, e
     \\[ w_{i,j} = \\eta\\left(\\frac{\\|x_i - x_j\\|^2}{\\varepsilon^2} \\right), \\]
     when \\(\\|x_i - x_j\\|\\leq \\varepsilon\\), and \\(w_{i,j}=0\\) otherwise.
     This type of weight matrix is only feasible in relatively low dimensions.
+    The diagonals are always zero.
    
     Parameters
     ----------
@@ -220,8 +224,6 @@ def epsilon_ball(data, epsilon, kernel='gaussian', features=None, epsilon_f=1, e
     eta : python function handle (optional)
         If provided, this overrides the kernel option and instead uses the weights
         \\[ w_{i,j} = \\eta\\left(\\frac{\\|x_i - x_j\\|^2}{\\varepsilon^2} \\right). \\]
-    zero_diagonal : bool (optional)
-        Whether to put zero on the diagonal, instead of \\(\\eta(0)\\). Default is False.
 
     Returns
     -------
@@ -248,19 +250,14 @@ def epsilon_ball(data, epsilon, kernel='gaussian', features=None, epsilon_f=1, e
         weights = weights*feature_weights
         fzero = fzero**2
 
-    #Symmetrize weights and add diagonal entries if they are not zero
-    if zero_diagonal:
-        weights = np.concatenate((weights,weights))
-        M1 = np.concatenate((M[:,0],M[:,1]))
-        M2 = np.concatenate((M[:,1],M[:,0]))
-    else:
-        weights = np.concatenate((weights,weights,fzero*np.ones(n,)))
-        M1 = np.concatenate((M[:,0],M[:,1],np.arange(0,n)))
-        M2 = np.concatenate((M[:,1],M[:,0],np.arange(0,n)))
+    weights = np.concatenate((weights,weights,fzero*np.ones(n,)))
+    M1 = np.concatenate((M[:,0],M[:,1],np.arange(0,n)))
+    M2 = np.concatenate((M[:,1],M[:,0],np.arange(0,n)))
 
     #Construct sparse matrix and convert to Compressed Sparse Row (CSR) format
     W = sparse.coo_matrix((weights, (M1,M2)),shape=(n,n))
 
+    W.setdiag(0)
     return W.tocsr()
 
 def __weights__(dists,epsilon,kernel,eta):
@@ -349,12 +346,12 @@ def knnsearch(X, k, method=None, similarity='euclidean', dataset=None, metric='r
 
         else: #Brute force knn search
 
-            knn_ind = np.array((n,k),dtype=int)
-            knn_dist = np.array((n,k))
+            knn_ind = np.zeros((n,k),dtype=int)
+            knn_dist = np.zeros((n,k))
             for i in range(n):
                 dist  = np.linalg.norm(X - X[i,:],axis=1) 
                 knn_ind[i,:] = np.argsort(dist)[:k]
-                knn_dist[i,:] = dist[knn_ind]
+                knn_dist[i,:] = dist[knn_ind[i,:]]
 
     elif method == 'annoy':
 
@@ -371,10 +368,35 @@ def knnsearch(X, k, method=None, similarity='euclidean', dataset=None, metric='r
         
         knn_dist = []
         knn_ind = []
+        eps = 1e-15
         for i in range(n):
-            A = u.get_nns_by_item(i, k, include_distances=True, search_k=-1)
-            knn_ind.append(A[0])
-            knn_dist.append(A[1])
+            #Get extra neighbors, in case there are mistakes
+            A = u.get_nns_by_item(i, min(2*k,n), include_distances=True)
+            ind = np.array(A[0])
+            #knn_dist.append(A[1]) #These distances are floating point (32-bit) precision
+            #The code below computes them more accurately
+            if similarity == 'euclidean':
+                dist = np.linalg.norm(X[i,:] - X[ind,:],axis=1)
+            elif similarity == 'angular':
+                vi = X[i,:]/np.maximum(np.linalg.norm(X[i,:]),eps)
+                vj = X[ind,:]/np.maximum(np.linalg.norm(X[ind,:],axis=1)[:,None],eps)
+                dist = np.linalg.norm(vi-vj,axis=1)
+            elif similarity == 'manhattan':
+                dist = np.linalg.norm(X[i,:] - X[ind,:],axis=1,ord=1)
+            elif similarity == 'hamming':
+                dist = A[1] #hamming is integer-valued, so no need to compute in double precision
+            elif similarity == 'dot':
+                dist = np.sum(X[i,:]*X[ind,:],axis=1)
+            else:
+                dist = A[1]
+
+            ind_sort = np.argsort(dist)[:k]
+            ind = ind[ind_sort]
+            dist = dist[ind_sort]
+            #print(np.max(np.absolute(dist - np.array(A[1]))))
+            knn_ind.append(ind)
+            knn_dist.append(dist)
+
 
         knn_ind = np.array(knn_ind)
         knn_dist = np.array(knn_dist)
